@@ -167,10 +167,14 @@ class Say(object):
         Print a horizontal line with an embedded title. 
         """
         opts = self.options.push(kwargs)
+        if not opts._callframe:
+            opts._callframe = inspect.currentframe().f_back
+        
+        formatted = _sprintf(name, opts._callframe) if is_string(name) else str(name)
 
         self.blank_lines(vsep, **opts)
         line = sep * width
-        self._output([ ' '.join([line, name, line]) ], opts)
+        self._output([ ' '.join([line, formatted, line]) ], opts)
         self.blank_lines(vsep, **opts)
     
     def blank_lines(self, n, **kwargs):
